(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     27435,        676]
NotebookOptionsPosition[     26041,        623]
NotebookOutlinePosition[     26935,        658]
CellTagsIndexPosition[     26865,        653]
WindowTitle->Phase Portrait and Field Directions of Two-Dimensional Linear \
Systems of ODEs - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Phase Portrait and Field Directions of Two-Dimensional Linear Systems of ODEs\
\
\>", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a1", ",", "b1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a2", ",", "b2"}], "}"}]}], "}"}]}], ";", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"VectorPlot", "[", 
       RowBox[{
        RowBox[{"m", ".", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
        RowBox[{"StreamPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"pt1", ",", "pt2", ",", "pt3", ",", "pt4"}], "}"}], 
          "}"}]}], ",", 
        RowBox[{"StreamStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Red", ",", "Thick"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"460", ",", "310"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Orange", ",", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "100"}], "#"}], ",", 
               RowBox[{"100", "#"}]}], "}"}], "]"}], "&"}], ",", 
           RowBox[{"Select", "[", 
            RowBox[{
             RowBox[{"Eigenvectors", "[", "m", "]"}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Im", "[", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[Equal]", "0"}], "&&", 
                RowBox[{
                 RowBox[{"Im", "[", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "]"}], "\[Equal]", "0"}]}],
                ")"}], "&"}]}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Column", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<\!\(\*OverscriptBox[\(x\), \(.\)]\)\>\"", ",", 
                    "Italic"}], "]"}], ",", 
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<\!\(\*OverscriptBox[\(y\), \(.\)]\)\>\"", ",", 
                    "Italic"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"Column", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\< = \>\"", ",", "\"\< = \>\""}], "}"}], "]"}], 
               ",", 
               RowBox[{
                RowBox[{"TableForm", "[", 
                 RowBox[{"m", ".", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<y\>\"", ",", "Italic"}], "]"}]}], "}"}]}], 
                 "]"}], "//", "N"}]}], "}"}], "]"}], "}"}], "]"}], ",", 
          "\"\<  \>\"", ",", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Eigenvalues:\>\"", ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"Chop", "@", 
                RowBox[{"N", "@", 
                 RowBox[{"Eigenvalues", "[", "m", "]"}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "2"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<  \>\"", ",", ",", 
          RowBox[{"Column", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Eigenvectors:\>\"", ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"Chop", "@", 
                RowBox[{"N", "@", 
                 RowBox[{
                  RowBox[{"Eigenvectors", "[", "m", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "2"}], "}"}]}], "]"}], ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"Chop", "@", 
                RowBox[{"N", "@", 
                 RowBox[{
                  RowBox[{"Eigenvectors", "[", "m", "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "2"}], "}"}]}], "]"}]}], " ", "}"}], 
           "]"}]}], "}"}], "]"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{
    "\"\<\!\(\*OverscriptBox[\(\(x\)\(\\\ \)\), \(.\)]\)= \!\(\*SubscriptBox[\
\(a\), \(1\)]\)x + \!\(\*SubscriptBox[\(b\), \(1\)]\)y\>\"", ",", "Bold"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a1", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(1\)]\)\>\""}], 
      "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b1", ",", "1", ",", "\"\<\!\(\*SubscriptBox[\(b\), \(1\)]\)\>\""}], 
      "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{
    "\"\<\!\(\*OverscriptBox[\(y\), \(.\)]\) = \!\(\*SubscriptBox[\(a\), \
\(2\)]\)x + \!\(\*SubscriptBox[\(b\), \(2\)]\)y\>\"", ",", "Bold"}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a2", ",", "2", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\)\>\""}], 
      "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b2", ",", 
       RowBox[{"-", "2"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(b\), \(2\)]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "10"}], ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5.1"}], ",", "4.8"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "10"}], "}"}], ",", "Locator"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt2", ",", 
       RowBox[{"{", 
        RowBox[{"4.9", ",", "5.1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "10"}], "}"}], ",", "Locator"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt3", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4.9"}], ",", 
         RowBox[{"-", "5"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "10"}], "}"}], ",", "Locator"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt4", ",", 
       RowBox[{"{", 
        RowBox[{"4.9", ",", 
         RowBox[{"-", "5.2"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", 
       RowBox[{"-", "10"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "10"}], "}"}], ",", "Locator"}], "}"}], ",", 
   RowBox[{"TrackedSymbols", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.443861320164259*^9, 3.443861332551259*^9}, {
   3.443861370535259*^9, 3.4438614286632586`*^9}, {3.443861472455259*^9, 
   3.443861511494259*^9}, {3.443861623039259*^9, 3.443861633862259*^9}, {
   3.4438620889902587`*^9, 3.4438621035902586`*^9}, {3.443862237231259*^9, 
   3.443862271239259*^9}, {3.4438623169672585`*^9, 3.443862364527259*^9}, {
   3.4438624183402586`*^9, 3.443862456456259*^9}, {3.4438625566232586`*^9, 
   3.443862567683259*^9}, {3.443863024553259*^9, 3.4438630305452585`*^9}, {
   3.443863657193259*^9, 3.443863674152259*^9}, {3.4438639315102587`*^9, 
   3.443863970112259*^9}, {3.4438647632002587`*^9, 3.443864824232259*^9}, {
   3.443864903320259*^9, 3.4438649074722586`*^9}, {3.4438650205622587`*^9, 
   3.4438650269932585`*^9}, 3.443865062744259*^9, {3.443865108581259*^9, 
   3.443865114224259*^9}, {3.443865148544259*^9, 3.4438651511682587`*^9}, {
   3.4438654785052586`*^9, 3.4438654988022585`*^9}, {3.4438655372722588`*^9, 
   3.443865568761259*^9}, {3.4438656324962587`*^9, 3.443865639048259*^9}, {
   3.4438657163842587`*^9, 3.443865752216259*^9}, {3.443865826072259*^9, 
   3.443865877896259*^9}, {3.443865926848259*^9, 3.443865950672259*^9}, {
   3.4438661768402586`*^9, 3.443866198360259*^9}, {3.4438662359042587`*^9, 
   3.443866310056259*^9}, {3.443866350945259*^9, 3.443866389610259*^9}, {
   3.443866423721259*^9, 3.4438664854252586`*^9}, {3.443866531785259*^9, 
   3.443866539945259*^9}, {3.4438666575382586`*^9, 3.443866745377259*^9}, {
   3.443866863297259*^9, 3.4438668762342587`*^9}, {3.4438669524832587`*^9, 
   3.4438669610422587`*^9}, {3.443867081353259*^9, 3.443867124992259*^9}, {
   3.4438672488252587`*^9, 3.443867333290259*^9}, {3.4438673703212585`*^9, 
   3.443867537554259*^9}, {3.443867569442259*^9, 3.443867575507259*^9}, {
   3.443881599564059*^9, 3.443881600491059*^9}, {3.4438816573950586`*^9, 
   3.443881682136059*^9}, {3.443881715004059*^9, 3.4438817490520587`*^9}, {
   3.443881790557059*^9, 3.4438818031050587`*^9}, {3.443881866500059*^9, 
   3.443881877382059*^9}, {3.443881920566059*^9, 3.4438819911870584`*^9}, {
   3.4438822739350586`*^9, 3.4438823051850586`*^9}, {3.4438823361830587`*^9, 
   3.443882352483059*^9}, {3.443882399044059*^9, 3.4438825378410587`*^9}, {
   3.443882588649059*^9, 3.443882595189059*^9}, {3.443882635148059*^9, 
   3.443882671878059*^9}, {3.443883003474059*^9, 3.4438830462390585`*^9}, {
   3.443883147391059*^9, 3.443883154537059*^9}, {3.443883580577059*^9, 
   3.443883668334059*^9}, {3.443883707950059*^9, 3.443883727727059*^9}, {
   3.443883763474059*^9, 3.443883787880059*^9}, {3.443883829330059*^9, 
   3.4438838365850587`*^9}, {3.443883869594059*^9, 3.4438839069560585`*^9}, {
   3.443883975530059*^9, 3.443883980811059*^9}, {3.443884068636059*^9, 
   3.4438841302880588`*^9}, {3.443884162613059*^9, 3.4438842476970587`*^9}, {
   3.443884281260059*^9, 3.4438842832890587`*^9}, {3.443884318603059*^9, 
   3.443884420662059*^9}, {3.443884505226059*^9, 3.4438845093680587`*^9}, {
   3.443884554825059*^9, 3.443884587536059*^9}, {3.4438846828050585`*^9, 
   3.443884842061059*^9}, {3.443884883231059*^9, 3.443884917728059*^9}, {
   3.443884955334059*^9, 3.4438850430190587`*^9}, {3.4438853587440586`*^9, 
   3.4438854566500587`*^9}, {3.443885495891059*^9, 3.443885684360059*^9}, {
   3.4439359212100587`*^9, 3.4439359441710587`*^9}, {3.4444935830272503`*^9, 
   3.4444935839622507`*^9}, {3.4444939030112505`*^9, 
   3.4444939257252502`*^9}, {3.4444939603072505`*^9, 3.4444939740592504`*^9}, 
   3.4444940588752503`*^9, {3.4444942156262503`*^9, 3.4444942340602503`*^9}, {
   3.4444942887152505`*^9, 3.4444943200582504`*^9}, {3.44449436132625*^9, 
   3.44449436705525*^9}, {3.4444945671922503`*^9, 3.44449457820125*^9}, 
   3.4444946290752506`*^9, 3.4444947747492504`*^9, 3.4444948259192505`*^9, {
   3.44449486166625*^9, 3.4444949133612504`*^9}, {3.4444953678992505`*^9, 
   3.4444953707972507`*^9}, {3.4445523230142508`*^9, 3.44455241401525*^9}, {
   3.4445570296342506`*^9, 3.4445570297662506`*^9}, {3.4445691388322506`*^9, 
   3.44456916817325*^9}, {3.4445692040062504`*^9, 3.4445692837612505`*^9}, {
   3.4445696108172503`*^9, 3.4445696279952507`*^9}, {3.4445696654072504`*^9, 
   3.44456969543025*^9}, {3.44456986382425*^9, 3.4445698818252506`*^9}, {
   3.4445699632162504`*^9, 3.4445699816462507`*^9}, {3.4445700285452504`*^9, 
   3.4445700395902505`*^9}, {3.4445700835262504`*^9, 
   3.4445701210572505`*^9}, {3.4445701913352504`*^9, 3.44457019488325*^9}, {
   3.44457025550325*^9, 3.4445702562172503`*^9}, {3.4445703040242505`*^9, 
   3.4445703465302505`*^9}, {3.4445704076842504`*^9, 
   3.4445704083692503`*^9}, {3.44457051969425*^9, 3.4445705509412503`*^9}, 
   3.4445928822572503`*^9, {3.4445929858062506`*^9, 3.44459298798225*^9}, {
   3.44459302580525*^9, 3.4445930519972506`*^9}, {3.44459311548425*^9, 
   3.4445931475822506`*^9}, {3.4445932122182503`*^9, 
   3.4445932219352503`*^9}, {3.44459326107425*^9, 3.4445932773462505`*^9}, {
   3.4445939262782507`*^9, 3.4445939270382504`*^9}, {3.4445942080682507`*^9, 
   3.44459421358125*^9}, {3.4445942480712504`*^9, 3.4445943133272505`*^9}, {
   3.44459434735925*^9, 3.44459435709525*^9}, {3.4445944012332506`*^9, 
   3.4445944075772505`*^9}, {3.4445944433872504`*^9, 
   3.4445944439192505`*^9}, {3.4445957138622503`*^9, 3.44459572158325*^9}, {
   3.4445978869942503`*^9, 3.4445979031392508`*^9}, {3.444667474743988*^9, 
   3.444667619957508*^9}, {3.444667650550567*^9, 3.4446677115796695`*^9}, {
   3.444667789162427*^9, 3.4446677892024307`*^9}, {3.4446698373938775`*^9, 
   3.4446699585181026`*^9}, {3.4446766840219336`*^9, 
   3.4446767185842123`*^9}, {3.444676785193161*^9, 3.444676823864789*^9}, {
   3.4446768669270134`*^9, 3.444676884880023*^9}, {3.4446769703013515`*^9, 
   3.444677013113578*^9}, {3.4446773195178666`*^9, 3.4446773262053237`*^9}, {
   3.4446773624082174`*^9, 3.4446774018142147`*^9}},
 CellTags->"S5.42.1",
 CellID->268841230]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 1, $CellContext`a2$$ = 
    2, $CellContext`b1$$ = 
    1, $CellContext`b2$$ = -2, $CellContext`pt1$$ = {-5.1, 
    4.8}, $CellContext`pt2$$ = {4.9, 
    5.1}, $CellContext`pt3$$ = {-4.9, -5}, $CellContext`pt4$$ = {4.9, -5.2}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Style[
       "\!\(\*OverscriptBox[\(\(x\)\(\\ \)\), \(.\)]\)= \
\!\(\*SubscriptBox[\(a\), \(1\)]\)x + \!\(\*SubscriptBox[\(b\), \(1\)]\)y", 
        Bold]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a1$$], 1, "\!\(\*SubscriptBox[\(a\), \(1\)]\)"}, -10,
       10}, {{
       Hold[$CellContext`b1$$], 1, "\!\(\*SubscriptBox[\(b\), \(1\)]\)"}, -10,
       10}, {
      Hold[
       Style[
       "\!\(\*OverscriptBox[\(y\), \(.\)]\) = \!\(\*SubscriptBox[\(a\), \
\(2\)]\)x + \!\(\*SubscriptBox[\(b\), \(2\)]\)y", Bold]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`a2$$], 2, "\!\(\*SubscriptBox[\(a\), \(2\)]\)"}, -10,
       10}, {{
       Hold[$CellContext`b2$$], -2, 
       "\!\(\*SubscriptBox[\(b\), \(2\)]\)"}, -10, 10}, {{
       Hold[$CellContext`pt1$$], {-5.1, 4.8}}, {-10, -10}, {10, 10}}, {{
       Hold[$CellContext`pt2$$], {4.9, 5.1}}, {-10, -10}, {10, 10}}, {{
       Hold[$CellContext`pt3$$], {-4.9, -5}}, {-10, -10}, {10, 10}}, {{
       Hold[$CellContext`pt4$$], {4.9, -5.2}}, {-10, -10}, {10, 10}}}, 
    Typeset`size$$ = {460., {153., 157.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a1$2105$$ = 0, $CellContext`b1$2106$$ = 
    0, $CellContext`pt1$2107$$ = {0, 0}, $CellContext`pt2$2108$$ = {0, 
    0}, $CellContext`pt3$2109$$ = {0, 0}, $CellContext`pt4$2110$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 1, $CellContext`a2$$ = 
        2, $CellContext`b1$$ = 
        1, $CellContext`b2$$ = -2, $CellContext`pt1$$ = {-5.1, 
         4.8}, $CellContext`pt2$$ = {4.9, 
         5.1}, $CellContext`pt3$$ = {-4.9, -5}, $CellContext`pt4$$ = {
         4.9, -5.2}}, "ControllerVariables" :> {
        Hold[$CellContext`a1$$, $CellContext`a1$2105$$, 0], 
        Hold[$CellContext`b1$$, $CellContext`b1$2106$$, 0], 
        Hold[$CellContext`pt1$$, $CellContext`pt1$2107$$, {0, 0}], 
        Hold[$CellContext`pt2$$, $CellContext`pt2$2108$$, {0, 0}], 
        Hold[$CellContext`pt3$$, $CellContext`pt3$2109$$, {0, 0}], 
        Hold[$CellContext`pt4$$, $CellContext`pt4$2110$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`m = {{$CellContext`a1$$, $CellContext`b1$$}, \
{$CellContext`a2$$, $CellContext`b2$$}}; Show[
         VectorPlot[
          
          Dot[$CellContext`m, {$CellContext`x, $CellContext`y}], \
{$CellContext`x, -10, 10}, {$CellContext`y, -10, 10}, 
          StreamPoints -> {{$CellContext`pt1$$, $CellContext`pt2$$, \
$CellContext`pt3$$, $CellContext`pt4$$}}, StreamStyle -> {Red, Thick}, 
          ImageSize -> {460, 310}], 
         Graphics[{Thick, Orange, 
           Map[Line[{(-100) #, 100 #}]& , 
            Select[
             Eigenvectors[$CellContext`m], And[Im[
                Part[#, 1]] == 0, Im[
                Part[#, 2]] == 0]& ]]}], PlotLabel -> Row[{
            Column[{
              Row[{
                Column[{
                  Style["\!\(\*OverscriptBox[\(x\), \(.\)]\)", Italic], 
                  Style["\!\(\*OverscriptBox[\(y\), \(.\)]\)", Italic]}], 
                Column[{" = ", " = "}], 
                N[
                 TableForm[
                  Dot[$CellContext`m, {
                    Style["x", Italic], 
                    Style["y", Italic]}]]]}]}], "  ", 
            Column[{"Eigenvalues:", 
              NumberForm[
               Chop[
                N[
                 Eigenvalues[$CellContext`m]]], {4, 2}]}], "  ", Null, 
            Column[{"Eigenvectors:", 
              NumberForm[
               Chop[
                N[
                 Part[
                  Eigenvectors[$CellContext`m], 1]]], {4, 2}], 
              NumberForm[
               Chop[
                N[
                 Part[
                  Eigenvectors[$CellContext`m], 2]]], {4, 2}]}]}]]), 
      "Specifications" :> {
        Style[
        "\!\(\*OverscriptBox[\(\(x\)\(\\ \)\), \(.\)]\)= \
\!\(\*SubscriptBox[\(a\), \(1\)]\)x + \!\(\*SubscriptBox[\(b\), \(1\)]\)y", 
         Bold], {{$CellContext`a1$$, 1, 
          "\!\(\*SubscriptBox[\(a\), \(1\)]\)"}, -10, 10, Appearance -> 
         "Labeled"}, {{$CellContext`b1$$, 1, 
          "\!\(\*SubscriptBox[\(b\), \(1\)]\)"}, -10, 10, Appearance -> 
         "Labeled"}, 
        Style[
        "\!\(\*OverscriptBox[\(y\), \(.\)]\) = \!\(\*SubscriptBox[\(a\), \
\(2\)]\)x + \!\(\*SubscriptBox[\(b\), \(2\)]\)y", 
         Bold], {{$CellContext`a2$$, 2, 
          "\!\(\*SubscriptBox[\(a\), \(2\)]\)"}, -10, 10, Appearance -> 
         "Labeled"}, {{$CellContext`b2$$, -2, 
          "\!\(\*SubscriptBox[\(b\), \(2\)]\)"}, -10, 10, Appearance -> 
         "Labeled"}, {{$CellContext`pt1$$, {-5.1, 4.8}}, {-10, -10}, {10, 10},
          ControlType -> 
         Locator}, {{$CellContext`pt2$$, {4.9, 5.1}}, {-10, -10}, {10, 10}, 
         ControlType -> 
         Locator}, {{$CellContext`pt3$$, {-4.9, -5}}, {-10, -10}, {10, 10}, 
         ControlType -> 
         Locator}, {{$CellContext`pt4$$, {4.9, -5.2}}, {-10, -10}, {10, 10}, 
         ControlType -> Locator}}, "Options" :> {TrackedSymbols -> True}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{511., {256., 261.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellTags->"S5.42.1",
 CellID->292594177],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Phase Portrait and Field Directions of Two-Dimensional Linear \
Systems of ODEs",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Santos Bravo Yuste",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Santos+Bravo+\
Yuste"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Santos+Bravo+Yuste"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
PhasePortraitAndFieldDirectionsOfTwoDimensionalLinearSystems"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Phase Portrait and Field Directions of Two-Dimensional Linear \
Systems of ODEs - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "S5.42.1"->{
  Cell[951, 33, 14194, 311, 70, "Input",
   CellTags->"S5.42.1",
   CellID->268841230],
  Cell[15160, 347, 6376, 135, 70, "Output",
   CellTags->"S5.42.1",
   CellID->292594177]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"S5.42.1", 26662, 643}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[669, 24, 279, 7, 70, "Section"],
Cell[951, 33, 14194, 311, 70, "Input",
 CellTags->"S5.42.1",
 CellID->268841230]
}, Open  ]],
Cell[15160, 347, 6376, 135, 70, "Output",
 CellTags->"S5.42.1",
 CellID->292594177],
Cell[CellGroupData[{
Cell[21561, 486, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[21937, 497, 1174, 32, 70, "Text"],
Cell[23114, 531, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[23454, 542, 448, 14, 70, "Text"],
Cell[CellGroupData[{
Cell[23927, 560, 847, 24, 70, "Text"],
Cell[24777, 586, 1236, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature ATz4TxSx3UlJhD0BaBR0qkXN *)
