(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32812,        872]
NotebookOptionsPosition[     31252,        815]
NotebookOutlinePosition[     31926,        841]
CellTagsIndexPosition[     31883,        838]
WindowTitle->Bifurcations in First-Order ODEs - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Bifurcations in First-Order ODEs", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RHS", " ", "of", " ", 
    RowBox[{"ODE", "'"}], "s"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Saddle", "[", 
     RowBox[{"x_", ",", "r_"}], "]"}], ":=", 
    RowBox[{"r", "+", 
     SuperscriptBox["x", "2"]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Transcritical", "[", 
     RowBox[{"x_", ",", "r_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"r", "*", "x"}], "-", 
     SuperscriptBox["x", "2"]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PitchForkSuper", "[", 
     RowBox[{"x_", ",", "r_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"r", "*", "x"}], "-", 
     SuperscriptBox["x", "3"]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PitchForkSub", "[", 
     RowBox[{"x_", ",", "r_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"r", "*", "x"}], "+", 
     SuperscriptBox["x", "3"]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.4500837149896674`*^9, {3.452507527204754*^9, 3.452507530079496*^9}, {
   3.45355632290625*^9, 3.45355633275*^9}, {3.453556453625*^9, 
   3.453556462578125*^9}, 3.45355721040625*^9, 3.453557396921875*^9, {
   3.4535587800625*^9, 3.453558809546875*^9}},
 CellID->439863718],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"fixed", " ", "points"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fixedPoints", "[", 
    RowBox[{"f_", ",", " ", "r_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"x", ",", " ", "r"}], "]"}], " ", "==", " ", "0"}], ",", " ", 
     "x"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.35696210375764*^9, {3.45355649096875*^9, 3.45355649971875*^9}},
 CellID->666060100],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"phase", " ", "portraits"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"markers", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"Disk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}], "]"}], ",", 
         "0.07"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}], "]"}], ",", 
         "0.07"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"phasePortrait", "[", 
     RowBox[{"f_", ",", "r_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"Show", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Plot", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x", ",", "r"}], " ", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1.3"}], ",", "1.3"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<d\[InvisibleSpace]x/d\[InvisibleSpace]t\>\"", ",", 
             "Italic"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Thickness", "[", "0.008", "]"}]}]}], "\[IndentingNewLine]", 
       "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0"}], "}"}], "}"}], "/.", 
         RowBox[{"fixedPoints", "[", 
          RowBox[{"f", ",", "r"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotMarkers", "\[Rule]", 
         RowBox[{"markers", "[", 
          RowBox[{"[", " ", 
           RowBox[{"1", "+", 
            RowBox[{"UnitStep", "[", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["\[PartialD]", "x"], 
                RowBox[{"f", "[", 
                 RowBox[{"x", ",", "r"}], "]"}]}], "]"}], "/.", 
              RowBox[{"fixedPoints", "[", 
               RowBox[{"f", ",", "r"}], "]"}]}], "]"}]}], " ", "]"}], 
          "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.3", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"370", ",", "225"}], "}"}]}]}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.35696210375764*^9, {3.453556533796875*^9, 3.45355654840625*^9}, {
   3.453556626078125*^9, 3.453556636234375*^9}, {3.45355863928125*^9, 
   3.45355864215625*^9}, {3.453589589765462*^9, 3.4535896007455597`*^9}, 
   3.45359004279576*^9, {3.453590160413521*^9, 3.453590182996779*^9}, 
   3.453733085884045*^9, {3.4537331562326183`*^9, 3.4537331630301895`*^9}},
 CellID->260343913],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"numerical", " ", "solution", " ", "of", " ", "ODE"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ODEsol", "[", 
     RowBox[{"f_", ",", "x0_", ",", "r_", ",", "tmax_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], ",", "r"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "\[Equal]", "x0"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "x", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AccuracyGoal", "\[Rule]", "3"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PrecisionGoal", "\[Rule]", "3"}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.35696210375764*^9, {3.45355682428125*^9, 3.453556835390625*^9}},
 CellID->51328306],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"solution", " ", "plots"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"solutionPlot", "[", 
      RowBox[{"f_", ",", "x0_", ",", "r_", ",", "tmax_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"sol", ",", "tp"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sol", "=", 
         RowBox[{"ODEsol", "[", 
          RowBox[{"f", ",", "x0", ",", "r", ",", "tmax"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"tp", "=", 
         RowBox[{"Min", "[", 
          RowBox[{"tmax", ",", 
           RowBox[{"sol", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2"}], 
             "]"}], "]"}]}], " ", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Show", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Plot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tp"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"1.3", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"Thickness", "[", "0.008", "]"}]}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"Plot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{"x", "/.", 
              RowBox[{"fixedPoints", "[", 
               RowBox[{"f", ",", "r"}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "\[Rule]", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"Thin", ",", "Black", ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"MatchQ", "[", 
                    RowBox[{"Transcritical", ",", "f"}], "]"}], "||", 
                    RowBox[{"MatchQ", "[", 
                    RowBox[{"PitchForkSub", ",", "f"}], "]"}]}], ",", 
                   RowBox[{"Dashing", "[", "0.01", "]"}], ",", 
                   RowBox[{"Dashing", "[", "1", "]"}]}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"Thin", ",", "Black", ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"MatchQ", "[", 
                    RowBox[{"Transcritical", ",", "f"}], "]"}], "||", 
                    RowBox[{"MatchQ", "[", 
                    RowBox[{"PitchForkSub", ",", "f"}], "]"}]}], ",", 
                   RowBox[{"Dashing", "[", "1", "]"}], ",", 
                   RowBox[{"Dashing", "[", "0.01", "]"}]}], "]"}]}], "}"}]}], 
              "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "tmax"}], "}"}], ",", 
             RowBox[{"1.3", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                "\"\<(\>\"", ",", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<t\>\"", ",", "Italic"}], "]"}], ",", 
                "\"\<)\>\""}], "}"}], "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"All", ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "10"}], ",", "10"}], "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1.3"}]}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"370", ",", "225"}], "}"}]}]}], "\[IndentingNewLine]", 
         "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"solutionPlot", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x0min_", ",", "x0max_", ",", "n_"}], "}"}], ",", "r_", ",", 
       "tmax_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"solutionPlot", "[", 
          RowBox[{"f", ",", "x0", ",", "r", ",", "tmax"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x0", ",", "x0min", ",", "x0max", ",", 
           FractionBox[
            RowBox[{"x0max", "-", "x0min"}], 
            RowBox[{"n", "-", "1"}]]}], "}"}]}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"370", ",", "225"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x0min", "=", 
     RowBox[{"-", "1.2"}]}], ";", " ", 
    RowBox[{"x0max", "=", "1.2"}], ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.35696210375764*^9, {3.453556880359375*^9, 3.453556911078125*^9}, {
   3.45355696765625*^9, 3.453556979703125*^9}, {3.4535598582781816`*^9, 
   3.453559864617669*^9}, {3.453589612817767*^9, 3.4535896210765924`*^9}, 
   3.4535900428017607`*^9, {3.4535901928047595`*^9, 3.4535902325047293`*^9}, {
   3.4537330977120943`*^9, 3.4537331070245347`*^9}, {3.45373317221863*^9, 
   3.4537331873295527`*^9}},
 CellID->253870578],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Quiet", "[", "\[IndentingNewLine]", 
    RowBox[{"GraphicsColumn", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"phasePortrait", "[", 
         RowBox[{"f", ",", "r"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"solutionPlot", "[", 
         RowBox[{"f", ",", 
          RowBox[{"{", 
           RowBox[{"x0min", ",", "x0max", ",", "n"}], "}"}], ",", "r", ",", 
          "tmax"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Spacings", "\[Rule]", "0"}]}], "\[IndentingNewLine]", "]"}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "Saddle", ",", "\"\<ODE\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Saddle", "\[Rule]", "\"\<saddle\>\""}], ",", 
       RowBox[{"Transcritical", "\[Rule]", "\"\<transcritical\>\""}], ",", 
       RowBox[{
       "PitchForkSuper", "\[Rule]", "\"\<supercritical pitchfork\>\""}], ",", 
       RowBox[{"PitchForkSub", "\[Rule]", "\"\<subcritical pitchfork\>\""}]}],
       "}"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"-", "1"}], ",", "\"\<parameter r\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "tmax", ",", "5", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(max\)]\)\>\""}],
       "}"}], ",", "0.1", ",", "10", ",", ".01", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "7", ",", "\"\<initial states\>\""}], "}"}], ",", "3",
      ",", "21", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "10"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.453557079796875*^9, {3.453557342609375*^9, 
   3.4535573671875*^9}, {3.453557427765625*^9, 3.453557428875*^9}, {
   3.453558311234375*^9, 3.453558317296875*^9}, 3.45355908015625*^9, {
   3.4535896291263976`*^9, 3.453589713626847*^9}, {3.453732842807476*^9, 
   3.453732848682438*^9}, {3.453743889838729*^9, 3.453743902698187*^9}, {
   3.4542135861061077`*^9, 3.4542135869654226`*^9}, {3.454213700285569*^9, 
   3.4542137009261494`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`f$$ = $CellContext`Saddle, $CellContext`n$$ \
= 7, $CellContext`r$$ = -1, $CellContext`tmax$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`f$$], $CellContext`Saddle, 
       "ODE"}, {$CellContext`Saddle -> "saddle", $CellContext`Transcritical -> 
       "transcritical", $CellContext`PitchForkSuper -> 
       "supercritical pitchfork", $CellContext`PitchForkSub -> 
       "subcritical pitchfork"}}, {{
       Hold[$CellContext`r$$], -1, "parameter r"}, -1, 1, 0.01}, {{
       Hold[$CellContext`tmax$$], 5, "\!\(\*SubscriptBox[\(t\), \(max\)]\)"}, 
      0.1, 10, 0.01}, {{
       Hold[$CellContext`n$$], 7, "initial states"}, 3, 21, 1}}, 
    Typeset`size$$ = {401., {229., 233.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = False, $CellContext`f$991$$ =
     False, $CellContext`r$992$$ = 0, $CellContext`tmax$993$$ = 
    0, $CellContext`n$994$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`f$$ = $CellContext`Saddle, \
$CellContext`n$$ = 7, $CellContext`r$$ = -1, $CellContext`tmax$$ = 5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`f$$, $CellContext`f$991$$, False], 
        Hold[$CellContext`r$$, $CellContext`r$992$$, 0], 
        Hold[$CellContext`tmax$$, $CellContext`tmax$993$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$994$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Quiet[
        GraphicsColumn[{
          $CellContext`phasePortrait[$CellContext`f$$, $CellContext`r$$], 
          $CellContext`solutionPlot[$CellContext`f$$, {$CellContext`x0min, \
$CellContext`x0max, $CellContext`n$$}, $CellContext`r$$, \
$CellContext`tmax$$]}, Spacings -> 0]], 
      "Specifications" :> {{{$CellContext`f$$, $CellContext`Saddle, 
          "ODE"}, {$CellContext`Saddle -> 
          "saddle", $CellContext`Transcritical -> 
          "transcritical", $CellContext`PitchForkSuper -> 
          "supercritical pitchfork", $CellContext`PitchForkSub -> 
          "subcritical pitchfork"}, ControlPlacement -> 
         Top}, {{$CellContext`r$$, -1, "parameter r"}, -1, 1, 0.01, 
         Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`tmax$$, 5, 
          "\!\(\*SubscriptBox[\(t\), \(max\)]\)"}, 0.1, 10, 0.01, Appearance -> 
         "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`n$$, 7, "initial states"}, 3, 21, 1, 
         Appearance -> "Labeled", ImageSize -> Tiny}}, 
      "Options" :> {
       ControlPlacement -> Left, SynchronousUpdating -> False, 
        AutorunSequencing -> {{1, 10}, {2, 10}, {3, 10}, {4, 10}}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{627., {272., 277.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`phasePortrait[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]]] := Show[
         Plot[
          $CellContext`f[$CellContext`x, $CellContext`r], {$CellContext`x, \
-1.3, 1.3}, AxesLabel -> {
            Style["x", Italic], 
            Style["d\[InvisibleSpace]x/d\[InvisibleSpace]t", Italic]}, 
          PlotStyle -> Thickness[0.008]], 
         ListPlot[
          ReplaceAll[{{$CellContext`x, 0}}, 
           $CellContext`fixedPoints[$CellContext`f, $CellContext`r]], 
          PlotMarkers -> Part[$CellContext`markers, 1 + UnitStep[
              ReplaceAll[
               Re[
                D[
                 $CellContext`f[$CellContext`x, $CellContext`r], \
$CellContext`x]], 
               $CellContext`fixedPoints[$CellContext`f, $CellContext`r]]]]], 
         Ticks -> {{-1, 1}, {-1, 1}}, PlotRange -> {1.3 {-1, 1}, 1.1 {-1, 1}},
          AxesOrigin -> {0, 0}, 
         ImageSize -> {370, 225}], $CellContext`fixedPoints[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]]] := 
       Solve[$CellContext`f[$CellContext`x, $CellContext`r] == 
         0, $CellContext`x], $CellContext`markers = {{
          Graphics[
           Disk[{0, 0}, 1]], 0.07}, {
          Graphics[
           Circle[{0, 0}, 1]], 0.07}}, $CellContext`solutionPlot[
         Pattern[$CellContext`f, 
          Blank[]], {
          Pattern[$CellContext`x0min, 
           Blank[]], 
          Pattern[$CellContext`x0max, 
           Blank[]], 
          Pattern[$CellContext`n, 
           Blank[]]}, 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`tmax, 
          Blank[]]] := Show[
         Table[
          $CellContext`solutionPlot[$CellContext`f, $CellContext`x0, \
$CellContext`r, $CellContext`tmax], {$CellContext`x0, $CellContext`x0min, \
$CellContext`x0max, ($CellContext`x0max - $CellContext`x0min)/($CellContext`n - 
           1)}], ImageSize -> {370, 225}], $CellContext`solutionPlot[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`tmax, 
          Blank[]]] := 
       Module[{$CellContext`sol, $CellContext`tp}, $CellContext`sol = \
$CellContext`ODEsol[$CellContext`f, $CellContext`x0, $CellContext`r, \
$CellContext`tmax]; $CellContext`tp = Min[$CellContext`tmax, 
            Part[$CellContext`sol, 1, 1, 2, 1, 1, 2]]; Show[
           Plot[
            Evaluate[
             ReplaceAll[
              $CellContext`x[$CellContext`t], $CellContext`sol]], \
{$CellContext`t, 0, $CellContext`tp}, PlotRange -> 1.3 {-1, 1}, PlotStyle -> 
            Thickness[0.008]], 
           Plot[
            Evaluate[
             ReplaceAll[$CellContext`x, 
              $CellContext`fixedPoints[$CellContext`f, $CellContext`r]]], \
{$CellContext`t, 0, $CellContext`tmax}, PlotStyle -> {{Thin, Black, 
               If[
                Or[
                 MatchQ[$CellContext`Transcritical, $CellContext`f], 
                 MatchQ[$CellContext`PitchForkSub, $CellContext`f]], 
                Dashing[0.01], 
                Dashing[1]]}, {Thin, Black, 
               If[
                Or[
                 MatchQ[$CellContext`Transcritical, $CellContext`f], 
                 MatchQ[$CellContext`PitchForkSub, $CellContext`f]], 
                Dashing[1], 
                Dashing[0.01]]}}], 
           PlotRange -> {{0, $CellContext`tmax}, 1.3 {-1, 1}}, AxesLabel -> {
             Style["t", Italic], 
             Row[{
               Style["x", Italic], "(", 
               Style["t", Italic], ")"}]}, Ticks -> {All, 
             Range[-10, 10]}, AxesOrigin -> {0, -1.3}, 
           ImageSize -> {370, 
            225}]], $CellContext`x0min = -1.2, $CellContext`x0max = 
       1.2, $CellContext`ODEsol[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]], 
         Pattern[$CellContext`tmax, 
          Blank[]]] := 
       NDSolve[{
         Derivative[1][$CellContext`x][$CellContext`t] == $CellContext`f[
            $CellContext`x[$CellContext`t], $CellContext`r], $CellContext`x[
           0] == $CellContext`x0}, $CellContext`x, {$CellContext`t, 
          0, $CellContext`tmax}, AccuracyGoal -> 3, PrecisionGoal -> 3], 
       Attributes[Derivative] = {
        NHoldAll, ReadProtected}, $CellContext`Transcritical[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`r, 
          
          Blank[]]] := $CellContext`r $CellContext`x - $CellContext`x^2, \
$CellContext`PitchForkSub[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`r, 
          
          Blank[]]] := $CellContext`r $CellContext`x + $CellContext`x^3, \
$CellContext`Saddle[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`r, 
          
          Blank[]]] := $CellContext`r + $CellContext`x^2, \
$CellContext`PitchForkSuper[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]]] := $CellContext`r $CellContext`x - $CellContext`x^3}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.4542135992458076`*^9, 3.4542137027228975`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Bifurcations in First-Order ODEs",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/BifurcationsInFirstOrderODEs/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/BifurcationsInFirstOrderODEs/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/BifurcationsInFirstOrderODEs/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/BifurcationsInFirstOrderODEs/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/BifurcationsInFirstOrderODEs/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Brian Vick",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Brian+Vick"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Brian+Vick"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
BifurcationsInFirstOrderODEs"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
},
AutoGeneratedPackage->None,
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{780, 650},
WindowMargins->{{246, Automatic}, {Automatic, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Bifurcations in First-Order ODEs - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[622, 23, 224, 4, 71, "Section"],
Cell[849, 29, 1245, 35, 112, "Input",
 InitializationCell->True,
 CellID->439863718],
Cell[2097, 66, 546, 16, 52, "Input",
 InitializationCell->True,
 CellID->666060100],
Cell[2646, 84, 4136, 109, 412, "Input",
 InitializationCell->True,
 CellID->260343913],
Cell[6785, 195, 1173, 32, 172, "Input",
 InitializationCell->True,
 CellID->51328306],
Cell[7961, 229, 6650, 160, 755, "Input",
 InitializationCell->True,
 CellID->253870578],
Cell[CellGroupData[{
Cell[14636, 393, 3415, 81, 372, "Input"],
Cell[18054, 476, 8929, 200, 566, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27032, 682, 373, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[27408, 693, 967, 28, 34, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28412, 726, 337, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[28752, 737, 427, 14, 18, "Text"],
Cell[29182, 753, 847, 24, 98, "Text"],
Cell[30032, 779, 1204, 33, 88, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature mQjtknJIOJ1zDA0T9CEh58vH *)
