(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     44394,        954]
NotebookOptionsPosition[     43322,        914]
NotebookOutlinePosition[     43940,        938]
CellTagsIndexPosition[     43897,        935]
WindowTitle->Interactive Curve Fitting - Source
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Interactive Curve Fitting", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d0", "=", "0.07"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"plt1", "=", "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"plt", "===", "Plot"}], ",", "ListPlot", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogPlot"}], ",", "ListLogPlot", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogLogPlot"}], ",", "ListLogLogPlot", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogLinearPlot"}], ",", "ListLogLinearPlot"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"range", "=", "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"plt", "===", "Plot"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "d1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "d2"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogPlot"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "d1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"d0", ",", "d2"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogLogPlot"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"d0", ",", "d1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"d0", ",", "d2"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"plt", "===", "LogLinearPlot"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"d0", ",", "d1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "d2"}], "}"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Panel", "[", "\[IndentingNewLine]", 
       RowBox[{"Column", "[", "\[IndentingNewLine]", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Click the graph on the left to place points.\>\"", ",", 
            "Bold"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Grid", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Column", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{"Button", "[", 
                    RowBox[{"\"\<reset\>\"", ",", 
                    RowBox[{
                    RowBox[{"p", "=", 
                    RowBox[{"{", "}"}]}], ";", 
                    RowBox[{"l", "=", 
                    RowBox[{"{", 
                    RowBox[{"{", "}"}], "}"}]}], ";", 
                    RowBox[{"regline", "=", 
                    RowBox[{"{", "}"}]}], ";", 
                    RowBox[{"d1", "=", "1"}], ";", 
                    RowBox[{"d2", "=", "1"}]}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", "100", "}"}]}]}], "]"}], "}"}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{"\"\<aspect ratio: \>\"", ",", 
                    RowBox[{"RadioButtonBar", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "ratio1", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "GoldenRatio"}], "\[Rule]", 
                    "\"\<1/golden ratio\>\""}], ",", 
                    RowBox[{"Automatic", "\[Rule]", "\"\<automatic\>\""}]}], 
                    "}"}]}], "]"}]}], "}"}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"EventHandler", "[", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Dynamic", "@", 
                    RowBox[{"Show", "[", 
                    RowBox[{
                    RowBox[{"l", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"Graphics", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Point", "[", "p", "]"}], "}"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d2"}], "}"}]}], "}"}]}]}], "]"}], ",", 
                    
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d2"}], "}"}]}], "}"}]}], ",", 
                    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
                    RowBox[{"AspectRatio", "\[Rule]", "ratio1"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"275", ",", "275"}], "}"}]}], ",", 
                    RowBox[{"Background", "\[Rule]", "White"}], ",", 
                    RowBox[{"FrameLabel", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<y\>\"", ",", "Italic"}], "]"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\"\<MouseDown\>\"", "\[RuleDelayed]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"p", ",", 
                    RowBox[{"MousePosition", "[", "\"\<Graphics\>\"", "]"}]}],
                     "]"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "p", "]"}], "\[GreaterEqual]", 
                    "2"}], ",", 
                    RowBox[{"l", "=", 
                    RowBox[{"Dynamic", "@", 
                    RowBox[{"Plot", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"regline", "=", 
                    RowBox[{
                    RowBox[{"(", "model", ")"}], "/.", 
                    RowBox[{"FindFit", "[", 
                    RowBox[{"p", ",", "model", ",", 
                    RowBox[{"{", 
                    RowBox[{"a", ",", "b"}], "}"}], ",", 
                    RowBox[{"{", "x", "}"}]}], "]"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "0", ",", "d1"}], "}"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "d2"}], "}"}]}], "}"}]}]}], "]"}]}]}]}],
                     "\[IndentingNewLine]", "]"}]}], ")"}]}]}], 
                   "\[IndentingNewLine]", "]"}]}], "}"}], ",", 
                RowBox[{"Spacings", "\[Rule]", "1"}]}], "]"}], ",", 
              RowBox[{"Spacer", "[", "15", "]"}], ",", "\[IndentingNewLine]", 
              
              RowBox[{"Column", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{"\"\<plotting: \>\"", ",", 
                    RowBox[{"SetterBar", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "plt", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Plot", "\[Rule]", "\"\<plot\>\""}], ",", 
                    RowBox[{"LogPlot", "\[Rule]", "\"\<log plot\>\""}], ",", 
                    RowBox[{"LogLogPlot", "\[Rule]", "\"\<log-log plot\>\""}],
                     ",", 
                    RowBox[{
                    "LogLinearPlot", "\[Rule]", "\"\<log-linear plot\>\""}]}],
                     "}"}]}], "]"}]}], "}"}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Row", "[", 
                   RowBox[{"{", 
                    RowBox[{"\"\<aspect ratio: \>\"", ",", 
                    RowBox[{"RadioButtonBar", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "ratio2", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "GoldenRatio"}], "\[Rule]", 
                    "\"\<1/golden ratio\>\""}], ",", 
                    RowBox[{"Automatic", "\[Rule]", "\"\<automatic\>\""}]}], 
                    "}"}]}], "]"}]}], "}"}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Dynamic", "@", 
                   RowBox[{"Show", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "p", "]"}], "\[GreaterEqual]", 
                    "2"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"plt", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{"regline", "=", 
                    RowBox[{
                    RowBox[{"(", "model", ")"}], "/.", 
                    RowBox[{"FindFit", "[", 
                    RowBox[{"p", ",", "model", ",", 
                    RowBox[{"{", 
                    RowBox[{"a", ",", "b"}], "}"}], ",", 
                    RowBox[{"{", "x", "}"}]}], "]"}]}]}], 
                    "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "0.0001", ",", "d1"}], "}"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"Evaluate", "[", "range", "]"}]}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}], 
                    ",", "\[IndentingNewLine]", "True", ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"plt", "[", 
                    RowBox[{
                    RowBox[{"x", " ", 
                    RowBox[{"d2", "/", "d1"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "0.0001", ",", "d1"}], "}"}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"Evaluate", "[", "range", "]"}]}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Opacity", "[", "0", "]"}], "}"}]}]}], "]"}]}], 
                    "\[IndentingNewLine]", "]"}], ",", 
                    RowBox[{"Which", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "p", "]"}], ">", "0"}], ",", " ", 
                    "\[IndentingNewLine]", 
                    RowBox[{"plt1", "[", 
                    RowBox[{"p", ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"Evaluate", "[", "range", "]"}]}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "True", ",", "\[IndentingNewLine]", 
                    RowBox[{"plt1", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"d0", ",", "d0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"d1", ",", "d2"}], "}"}]}], "}"}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"Evaluate", "[", "range", "]"}]}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Opacity", "[", "0", "]"}], "}"}]}]}], "]"}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
                    RowBox[{"FrameLabel", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<x\>\"", ",", "Italic"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<y\>\"", ",", "Italic"}], "]"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"275", ",", "275"}], "}"}]}], ",", 
                    RowBox[{"Background", "\[Rule]", "White"}], ",", 
                    RowBox[{"Axes", "\[Rule]", "None"}], ",", 
                    RowBox[{"AspectRatio", "\[Rule]", "ratio2"}]}], "]"}]}]}],
                  "\[IndentingNewLine]", "}"}], ",", 
                RowBox[{"Spacings", "\[Rule]", "1"}]}], "\[IndentingNewLine]",
                "]"}]}], "\[IndentingNewLine]", "}"}], "}"}], "]"}], ",", 
          "\[IndentingNewLine]", ",", 
          RowBox[{"Row", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<fitting curve: \>\"", ",", 
              RowBox[{"Text", "@", 
               RowBox[{"TraditionalForm", "[", 
                RowBox[{"Dynamic", "[", "regline", "]"}], "]"}]}]}], "}"}], 
            ",", 
            RowBox[{"Background", "\[Rule]", "White"}], ",", 
            RowBox[{"FrameMargins", "\[Rule]", "5"}], ",", 
            RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"{", "}"}], ",", "\"\<\>\""}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"model", ",", 
       RowBox[{
        RowBox[{"a", " ", "x"}], "+", "b"}], ",", "\"\<model\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"a", " ", "x"}], "+", "b"}], ",", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"a", " ", "x"}], "+", "b"}]], ",", 
       RowBox[{"b", "*", 
        SuperscriptBox["x", 
         RowBox[{"a", " "}]]}], ",", 
       RowBox[{
        RowBox[{"a", " ", 
         RowBox[{"Log", "[", "x", "]"}]}], "+", "b"}]}], "}"}], ",", 
     "SetterBar"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d1", ",", "1", ",", "\"\<data x-range\>\""}], "}"}], ",", "1", 
     ",", "100", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d2", ",", "1", ",", "\"\<y-range\>\""}], "}"}], ",", "1", ",", 
     "100", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"{", 
        RowBox[{"{", "}"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"regline", ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"plt", ",", "Plot"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"plt1", ",", "ListPlot"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"range", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "d1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "d2"}], "}"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ratio1", ",", 
       RowBox[{"1", "/", "GoldenRatio"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ratio2", ",", 
       RowBox[{"1", "/", "GoldenRatio"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"FrameMargins", "\[Rule]", 
    RowBox[{"-", "7"}]}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3", ",", "4"}], "}"}]}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.404910033086368*^9, 3.40491004790768*^9}, {
   3.4351686670625*^9, 3.435168741828125*^9}, {3.435168800984375*^9, 
   3.435168848296875*^9}, {3.435168935953125*^9, 3.435168938109375*^9}, {
   3.435169013921875*^9, 3.435169020734375*^9}, {3.4351692035625*^9, 
   3.43516920415625*^9}, {3.43516923709375*^9, 3.43516924178125*^9}, {
   3.435169275375*^9, 3.43516939428125*^9}, {3.43516942434375*^9, 
   3.435169469953125*^9}, {3.435169599234375*^9, 3.43516966484375*^9}, {
   3.43516969696875*^9, 3.435169735140625*^9}, {3.435169767453125*^9, 
   3.435169782484375*^9}, {3.435169903796875*^9, 3.435169907046875*^9}, {
   3.4351700695625*^9, 3.43517007225*^9}, {3.435170117859375*^9, 
   3.435170131328125*^9}, {3.43517033915625*^9, 3.435170360203125*^9}, {
   3.4351704440625*^9, 3.43517061946875*^9}, {3.4351706505625*^9, 
   3.435170659984375*^9}, {3.43517071840625*^9, 3.435170763109375*^9}, {
   3.43517080078125*^9, 3.435170801796875*^9}, {3.435170864515625*^9, 
   3.435170870421875*^9}, {3.435170900953125*^9, 3.435170959890625*^9}, {
   3.435171000453125*^9, 3.435171018765625*^9}, {3.43517109771875*^9, 
   3.435171122984375*^9}, {3.43517118465625*^9, 3.435171226265625*^9}, {
   3.43517134440625*^9, 3.435171579828125*^9}, {3.435171625296875*^9, 
   3.435171659375*^9}, {3.43517169225*^9, 3.435171697328125*^9}, {
   3.435171728453125*^9, 3.435171732203125*^9}, {3.43517176459375*^9, 
   3.435171800109375*^9}, {3.435171942734375*^9, 3.43517194590625*^9}, {
   3.435172085828125*^9, 3.43517208775*^9}, {3.435172125390625*^9, 
   3.435172128984375*^9}, {3.435172178828125*^9, 3.435172207203125*^9}, {
   3.435172293265625*^9, 3.435172294578125*^9}, {3.435172327328125*^9, 
   3.435172348015625*^9}, {3.436968998046875*^9, 3.4369690061875*^9}, {
   3.43696908196875*^9, 3.43696916615625*^9}, {3.43696927803125*^9, 
   3.436969336640625*^9}, {3.436969376859375*^9, 3.436969379296875*^9}, {
   3.4369694096875*^9, 3.43696945828125*^9}, {3.4369695218125*^9, 
   3.436969545859375*^9}, {3.436969653421875*^9, 3.436969654078125*^9}, {
   3.43696979478125*^9, 3.436969795703125*^9}, {3.436969834109375*^9, 
   3.436969839828125*^9}, {3.43696989290625*^9, 3.43696989890625*^9}, {
   3.436969983609375*^9, 3.4369699840625*^9}, {3.436970137265625*^9, 
   3.436970158921875*^9}, {3.436970208046875*^9, 3.43697044359375*^9}, {
   3.43697051603125*^9, 3.436970562703125*^9}, {3.43697064453125*^9, 
   3.436970698859375*^9}, {3.43697074790625*^9, 3.436970777265625*^9}, {
   3.436970816984375*^9, 3.436970843765625*^9}, {3.43697134975*^9, 
   3.436971373703125*^9}, {3.436971440859375*^9, 3.436971498125*^9}, 
   3.43697154096875*^9, {3.436971584546875*^9, 3.43697168353125*^9}, {
   3.4369717805*^9, 3.436971787875*^9}, {3.43697182128125*^9, 
   3.436971844203125*^9}, {3.436971913140625*^9, 3.4369719719375*^9}, {
   3.436972024015625*^9, 3.436972070140625*^9}, {3.43697211875*^9, 
   3.43697211928125*^9}, 3.436972153328125*^9, {3.436972192390625*^9, 
   3.436972209359375*^9}, {3.436972257234375*^9, 3.4369722959375*^9}, {
   3.43697236534375*^9, 3.436972366390625*^9}, 3.4369724029375*^9, {
   3.436972443359375*^9, 3.43697248425*^9}, {3.436972853328125*^9, 
   3.436972873671875*^9}, {3.436972979171875*^9, 3.436973043453125*^9}, {
   3.436973091203125*^9, 3.436973139234375*^9}, {3.4369731963125*^9, 
   3.436973251984375*^9}, {3.436973284140625*^9, 3.4369733110625*^9}, {
   3.43697338759375*^9, 3.436973424375*^9}, {3.436973522078125*^9, 
   3.436973542609375*^9}, {3.436973581203125*^9, 3.4369735815*^9}, 
   3.436973673890625*^9, 3.436973717328125*^9, {3.436973765046875*^9, 
   3.43697376528125*^9}, {3.436973862953125*^9, 3.436973863296875*^9}, {
   3.43697400625*^9, 3.43697400934375*^9}, {3.43697408615625*^9, 
   3.436974153296875*^9}, {3.436974223328125*^9, 3.436974251921875*^9}, {
   3.436974291828125*^9, 3.436974339375*^9}, {3.436974373390625*^9, 
   3.4369744015*^9}, 3.436974500546875*^9, {3.436974539390625*^9, 
   3.436974544453125*^9}, {3.436974593515625*^9, 3.43697459496875*^9}, {
   3.4369747569375*^9, 3.43697476025*^9}, {3.436974791*^9, 
   3.43697479165625*^9}, {3.43697496221875*^9, 3.4369749631875*^9}, {
   3.43697500503125*^9, 3.4369750083125*^9}, {3.436975180421875*^9, 
   3.436975180828125*^9}, {3.436975216671875*^9, 3.436975227578125*^9}, {
   3.4369753061875*^9, 3.43697530690625*^9}, {3.436975384703125*^9, 
   3.436975385015625*^9}, {3.436975489015625*^9, 3.4369754943125*^9}, {
   3.43697583590625*^9, 3.436975849234375*^9}, {3.436975917921875*^9, 
   3.436975949390625*^9}, {3.436975993953125*^9, 3.436976007578125*^9}, {
   3.4369762424375*^9, 3.436976264265625*^9}, {3.4369763089375*^9, 
   3.436976367984375*^9}, 3.436976443171875*^9, {3.436976530890625*^9, 
   3.4369765539375*^9}, {3.436976609953125*^9, 3.436976613625*^9}, {
   3.4369766468125*^9, 3.436976652875*^9}, {3.43697672375*^9, 
   3.436976742828125*^9}, {3.4369769531875*^9, 3.43697696228125*^9}, {
   3.436977083765625*^9, 3.4369770945*^9}, {3.437066652671875*^9, 
   3.437066710578125*^9}, {3.437066750875*^9, 3.43706683109375*^9}, {
   3.437066916*^9, 3.43706692115625*^9}, {3.437066982296875*^9, 
   3.4370670035*^9}, {3.437067146546875*^9, 3.43706731596875*^9}, {
   3.43706742809375*^9, 3.437067531046875*^9}, {3.43706756975*^9, 
   3.4370675724375*^9}, {3.437067644328125*^9, 3.4370676516875*^9}, {
   3.437067723453125*^9, 3.437067768328125*^9}, {3.437067888359375*^9, 
   3.437067906734375*^9}, {3.4370681636875*^9, 3.43706825115625*^9}, {
   3.437068581046875*^9, 3.437068660578125*^9}, {3.437068717390625*^9, 
   3.437068852765625*^9}, {3.437069040078125*^9, 3.437069052359375*^9}, {
   3.437069176765625*^9, 3.4370691804375*^9}, 3.43706932415625*^9, {
   3.437069385296875*^9, 3.437069406828125*^9}, {3.4370695775625*^9, 
   3.437069625328125*^9}, {3.437069688796875*^9, 3.437069736453125*^9}, {
   3.437069779875*^9, 3.437069797609375*^9}, 3.437069837859375*^9, {
   3.437070005484375*^9, 3.437070023921875*^9}, {3.437070058171875*^9, 
   3.437070068*^9}, {3.43707010825*^9, 3.437070179203125*^9}, {
   3.437070346234375*^9, 3.43707035703125*^9}, {3.437070399609375*^9, 
   3.437070422953125*^9}, {3.4370705561875*^9, 3.437070556640625*^9}, {
   3.437070651140625*^9, 3.437070656328125*^9}, {3.437070729203125*^9, 
   3.437070734890625*^9}, 3.437070776515625*^9, 3.437070843375*^9, {
   3.437070906109375*^9, 3.437070964046875*^9}, {3.43707114921875*^9, 
   3.43707116240625*^9}, {3.437071480421875*^9, 3.4370717123125*^9}, {
   3.43707180925*^9, 3.437071836703125*^9}, {3.437071909375*^9, 
   3.437071958921875*^9}, {3.437072020171875*^9, 3.4370720655625*^9}, {
   3.4370721514375*^9, 3.43707215521875*^9}, {3.43707219721875*^9, 
   3.437072224734375*^9}, {3.4370723083125*^9, 3.43707237753125*^9}, 
   3.437072928140625*^9, {3.437073222828125*^9, 3.437073233609375*^9}, {
   3.43707330534375*^9, 3.437073306828125*^9}, {3.437073349328125*^9, 
   3.437073349828125*^9}, {3.43707341575*^9, 3.43707343275*^9}, {
   3.437073472453125*^9, 3.437073484515625*^9}, {3.437073531234375*^9, 
   3.437073562296875*^9}, {3.437073602796875*^9, 3.437073616625*^9}, {
   3.437073679515625*^9, 3.437073682203125*^9}, {3.437073886328125*^9, 
   3.437073901984375*^9}, {3.437074004171875*^9, 3.4370740049375*^9}, {
   3.43707417603125*^9, 3.43707421421875*^9}, {3.4370743181875*^9, 
   3.437074319484375*^9}, {3.43707449734375*^9, 3.43707451890625*^9}, {
   3.43707490753125*^9, 3.437074907921875*^9}, 3.43707510725*^9, 
   3.4370751719375*^9, {3.437075243875*^9, 3.437075248203125*^9}, {
   3.4370753131875*^9, 3.43707533359375*^9}, {3.43707649721875*^9, 
   3.437076540203125*^9}, {3.43707657284375*^9, 3.437076778828125*^9}, {
   3.43707694625*^9, 3.437076969046875*^9}, {3.437077027390625*^9, 
   3.4370770455625*^9}, {3.43707711696875*^9, 3.437077118890625*^9}, {
   3.43710553115625*^9, 3.437105531796875*^9}, {3.437105741203125*^9, 
   3.437105741796875*^9}, {3.43710586265625*^9, 3.437105872671875*^9}, 
   3.437105903265625*^9, {3.437106556390625*^9, 3.437106557875*^9}, {
   3.437106652*^9, 3.43710665246875*^9}, {3.437106693234375*^9, 
   3.437106694234375*^9}, {3.437106843078125*^9, 3.437106849625*^9}, {
   3.437106914328125*^9, 3.437106988875*^9}, {3.437107290078125*^9, 
   3.437107315984375*^9}, {3.437107933984375*^9, 3.43710793534375*^9}, {
   3.437107993171875*^9, 3.437107999203125*^9}, {3.437108180453125*^9, 
   3.437108206875*^9}, {3.437108347265625*^9, 3.43710835065625*^9}, {
   3.4372279683391914`*^9, 3.4372280762009764`*^9}, {3.4372281093962955`*^9, 
   3.437228130450401*^9}, {3.4372281796423197`*^9, 3.4372282225346084`*^9}, {
   3.437250078905027*^9, 3.437250087090845*^9}, {3.4372511720355635`*^9, 
   3.437251257380406*^9}, {3.4372513008653374`*^9, 3.437251309271695*^9}, {
   3.437251359428587*^9, 3.4372514086792173`*^9}, {3.437315580346446*^9, 
   3.43731558679891*^9}, {3.437387271*^9, 3.4373872788125*^9}, {
   3.43738733446875*^9, 3.437387339796875*^9}, {3.4373873881875*^9, 
   3.43738738990625*^9}, {3.437387604375*^9, 3.4373876603125*^9}, {
   3.437387824859375*^9, 3.437387896046875*^9}, {3.4373879505*^9, 
   3.437388001359375*^9}, {3.437388034171875*^9, 3.437388048140625*^9}, {
   3.4373881695625*^9, 3.437388189984375*^9}, {3.437388249328125*^9, 
   3.437388267671875*^9}, {3.43738840484375*^9, 3.437388411453125*^9}, {
   3.437388540234375*^9, 3.43738854821875*^9}, {3.43738929253125*^9, 
   3.437389434890625*^9}, {3.43738949171875*^9, 3.43738949240625*^9}, {
   3.437389585421875*^9, 3.43738959625*^9}, {3.437389689359375*^9, 
   3.437389692921875*^9}, {3.437389726296875*^9, 3.437389726578125*^9}, {
   3.437389785046875*^9, 3.437389870609375*^9}, {3.4373899286875*^9, 
   3.437389933875*^9}, {3.43738996703125*^9, 3.43738997453125*^9}, {
   3.437390128*^9, 3.437390132515625*^9}, {3.43739016546875*^9, 
   3.437390179703125*^9}, {3.437390408078125*^9, 3.437390443640625*^9}, 
   3.43739051421875*^9, {3.43739071746875*^9, 3.43739075103125*^9}, {
   3.4373966124375*^9, 3.4373966256875*^9}, {3.43739669296875*^9, 
   3.43739671646875*^9}, {3.437396769625*^9, 3.437396794171875*^9}, {
   3.437396826828125*^9, 3.43739684725*^9}, {3.437396886109375*^9, 
   3.437396887859375*^9}, {3.43741179525*^9, 3.437411849734375*^9}, {
   3.437749814009255*^9, 3.4377498240182557`*^9}},
 CellID->176273040]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d1$$ = 1, $CellContext`d2$$ = 
    1, $CellContext`l$$ = {{}}, $CellContext`model$$ = $CellContext`b + \
$CellContext`a $CellContext`x, $CellContext`p$$ = {}, $CellContext`plt$$ = 
    Plot, $CellContext`plt1$$ = 
    ListPlot, $CellContext`range$$ = {{0, $CellContext`d1$$}, {
     0, $CellContext`d2$$}}, $CellContext`ratio1$$ = 
    GoldenRatio^(-1), $CellContext`ratio2$$ = 
    GoldenRatio^(-1), $CellContext`regline$$ = {}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`p$$], {}, ""}}, {{
       Hold[$CellContext`model$$], $CellContext`b + $CellContext`a \
$CellContext`x, "model"}, {$CellContext`b + $CellContext`a $CellContext`x, 
       E^($CellContext`b + $CellContext`a $CellContext`x), $CellContext`b \
$CellContext`x^$CellContext`a, $CellContext`b + $CellContext`a 
        Log[$CellContext`x]}}, {{
       Hold[$CellContext`d1$$], 1, "data x-range"}, 1, 100, 1}, {{
       Hold[$CellContext`d2$$], 1, "y-range"}, 1, 100, 1}, {{
       Hold[$CellContext`l$$], {{}}}}, {{
       Hold[$CellContext`regline$$], {}}}, {{
       Hold[$CellContext`plt$$], Plot}}, {{
       Hold[$CellContext`plt1$$], ListPlot}}, {{
       Hold[$CellContext`range$$], {{0, $CellContext`d1$$}, {
        0, $CellContext`d2$$}}}}, {{
       Hold[$CellContext`ratio1$$], GoldenRatio^(-1)}}, {{
       Hold[$CellContext`ratio2$$], GoldenRatio^(-1)}}}, Typeset`size$$ = {
    604., {210.5, 217.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`model$32162$$ = 
    0, $CellContext`d1$32163$$ = 0, $CellContext`d2$32164$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d1$$ = 1, $CellContext`d2$$ = 
        1, $CellContext`l$$ = {{}}, $CellContext`model$$ = $CellContext`b + \
$CellContext`a $CellContext`x, $CellContext`p$$ = {}, $CellContext`plt$$ = 
        Plot, $CellContext`plt1$$ = 
        ListPlot, $CellContext`range$$ = {{0, $CellContext`d1$$}, {
          0, $CellContext`d2$$}}, $CellContext`ratio1$$ = 
        GoldenRatio^(-1), $CellContext`ratio2$$ = 
        GoldenRatio^(-1), $CellContext`regline$$ = {}}, "ControllerVariables" :> {
        Hold[$CellContext`model$$, $CellContext`model$32162$$, 0], 
        Hold[$CellContext`d1$$, $CellContext`d1$32163$$, 0], 
        Hold[$CellContext`d2$$, $CellContext`d2$32164$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      DynamicModule[{$CellContext`d0 = 0.07}, $CellContext`plt1$$ = 
         Which[$CellContext`plt$$ === Plot, ListPlot, $CellContext`plt$$ === 
           LogPlot, ListLogPlot, $CellContext`plt$$ === LogLogPlot, 
           ListLogLogPlot, $CellContext`plt$$ === LogLinearPlot, 
           ListLogLinearPlot]; $CellContext`range$$ = 
         Which[$CellContext`plt$$ === 
           Plot, {{0, $CellContext`d1$$}, {
            0, $CellContext`d2$$}}, $CellContext`plt$$ === 
           LogPlot, {{
            0, $CellContext`d1$$}, {$CellContext`d0, $CellContext`d2$$}}, \
$CellContext`plt$$ === 
           LogLogPlot, {{$CellContext`d0, $CellContext`d1$$}, \
{$CellContext`d0, $CellContext`d2$$}}, $CellContext`plt$$ === 
           LogLinearPlot, {{$CellContext`d0, $CellContext`d1$$}, {
            0, $CellContext`d2$$}}]; Panel[
          Column[{
            Style["Click the graph on the left to place points.", Bold], 
            Grid[{{
               Column[{
                 Row[{
                   Button[
                   "reset", $CellContext`p$$ = {}; $CellContext`l$$ = {{}}; \
$CellContext`regline$$ = {}; $CellContext`d1$$ = 1; $CellContext`d2$$ = 1, 
                    ImageSize -> {100}]}], 
                 Row[{"aspect ratio: ", 
                   RadioButtonBar[
                    Dynamic[$CellContext`ratio1$$], {
                    1/GoldenRatio -> "1/golden ratio", Automatic -> 
                    "automatic"}]}], 
                 EventHandler[
                  Dynamic[
                   Show[
                    Part[$CellContext`l$$, 1], 
                    Graphics[{
                    Point[$CellContext`p$$]}, 
                    PlotRange -> {{0, $CellContext`d1$$}, {
                    0, $CellContext`d2$$}}], 
                    PlotRange -> {{0, $CellContext`d1$$}, {
                    0, $CellContext`d2$$}}, Frame -> True, 
                    AspectRatio -> $CellContext`ratio1$$, 
                    ImageSize -> {275, 275}, Background -> White, FrameLabel -> {
                    Style["x", Italic], 
                    Style["y", Italic]}, Axes -> None]], 
                  "MouseDown" :> (AppendTo[$CellContext`p$$, 
                    MousePosition["Graphics"]]; 
                   If[Length[$CellContext`p$$] >= 2, $CellContext`l$$ = 
                    Dynamic[
                    Plot[
                    
                    Evaluate[$CellContext`regline$$ = 
                    ReplaceAll[$CellContext`model$$, 
                    
                    FindFit[$CellContext`p$$, $CellContext`model$$, \
{$CellContext`a, $CellContext`b}, {$CellContext`x}]]], {$CellContext`x, 
                    0, $CellContext`d1$$}, 
                    PlotRange -> {{0, $CellContext`d1$$}, {
                    0, $CellContext`d2$$}}]]])]}, Spacings -> 1], 
               Spacer[15], 
               Column[{
                 Row[{"plotting: ", 
                   SetterBar[
                    Dynamic[$CellContext`plt$$], {
                    Plot -> "plot", LogPlot -> "log plot", LogLogPlot -> 
                    "log-log plot", LogLinearPlot -> "log-linear plot"}]}], 
                 Row[{"aspect ratio: ", 
                   RadioButtonBar[
                    Dynamic[$CellContext`ratio2$$], {
                    1/GoldenRatio -> "1/golden ratio", Automatic -> 
                    "automatic"}]}], 
                 Dynamic[
                  Show[
                   Which[Length[$CellContext`p$$] >= 2, 
                    $CellContext`plt$$[
                    
                    Evaluate[{$CellContext`regline$$ = 
                    ReplaceAll[$CellContext`model$$, 
                    
                    FindFit[$CellContext`p$$, $CellContext`model$$, \
{$CellContext`a, $CellContext`b}, {$CellContext`x}]]}], {$CellContext`x, 
                    0.0001, $CellContext`d1$$}, PlotRange -> 
                    Evaluate[$CellContext`range$$], GridLines -> Automatic], 
                    True, 
                    $CellContext`plt$$[$CellContext`x \
($CellContext`d2$$/$CellContext`d1$$), {$CellContext`x, 
                    0.0001, $CellContext`d1$$}, GridLines -> Automatic, 
                    PlotRange -> Evaluate[$CellContext`range$$], PlotStyle -> {
                    Opacity[0]}]], 
                   Which[Length[$CellContext`p$$] > 0, 
                    $CellContext`plt1$$[$CellContext`p$$, GridLines -> 
                    Automatic, PlotRange -> Evaluate[$CellContext`range$$]], 
                    True, 
                    $CellContext`plt1$$[{{$CellContext`d0, $CellContext`d0}, \
{$CellContext`d1$$, $CellContext`d2$$}}, GridLines -> Automatic, PlotRange -> 
                    Evaluate[$CellContext`range$$], PlotStyle -> {
                    Opacity[0]}]], Frame -> True, FrameLabel -> {
                    Style["x", Italic], 
                    Style["y", Italic]}, ImageSize -> {275, 275}, Background -> 
                   White, Axes -> None, 
                   AspectRatio -> $CellContext`ratio2$$]]}, Spacings -> 1]}}],
             Null, 
            Row[{"fitting curve: ", 
              Text[
               TraditionalForm[
                Dynamic[$CellContext`regline$$]]]}, Background -> White, 
             FrameMargins -> 5, Frame -> True]}]]], 
      "Specifications" :> {{{$CellContext`p$$, {}, ""}, ControlType -> 
         None}, {{$CellContext`model$$, $CellContext`b + $CellContext`a \
$CellContext`x, "model"}, {$CellContext`b + $CellContext`a $CellContext`x, 
          E^($CellContext`b + $CellContext`a $CellContext`x), $CellContext`b \
$CellContext`x^$CellContext`a, $CellContext`b + $CellContext`a 
           Log[$CellContext`x]}, ControlType -> 
         SetterBar}, {{$CellContext`d1$$, 1, "data x-range"}, 1, 100, 1, 
         Appearance -> "Labeled"}, {{$CellContext`d2$$, 1, "y-range"}, 1, 100,
          1, Appearance -> "Labeled"}, {{$CellContext`l$$, {{}}}, ControlType -> 
         None}, {{$CellContext`regline$$, {}}, ControlType -> 
         None}, {{$CellContext`plt$$, Plot}, ControlType -> 
         None}, {{$CellContext`plt1$$, ListPlot}, ControlType -> 
         None}, {{$CellContext`range$$, {{0, $CellContext`d1$$}, {
           0, $CellContext`d2$$}}}, ControlType -> 
         None}, {{$CellContext`ratio1$$, GoldenRatio^(-1)}, ControlType -> 
         None}, {{$CellContext`ratio2$$, GoldenRatio^(-1)}, ControlType -> 
         None}}, "Options" :> {
       FrameMargins -> -7, AutorunSequencing -> {2, 3, 4}, ControlPlacement -> 
        Top}, "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{615., {266., 271.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->90306286],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Interactive Curve Fitting",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/InteractiveCurveFitting/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/InteractiveCurveFitting/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/InteractiveCurveFitting/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/InteractiveCurveFitting/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/InteractiveCurveFitting/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Janos Karsai",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Janos+Karsai"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Janos+Karsai"],
 " (University of Szeged, Hungary)"
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " system (Version 6 or higher) is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
InteractiveCurveFitting"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{780, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Interactive Curve Fitting - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[615, 23, 217, 4, 70, "Section"],
Cell[835, 29, 28389, 563, 70, "Input",
 CellID->176273040]
}, Open  ]],
Cell[29239, 595, 9850, 185, 70, "Output",
 CellID->90306286],
Cell[CellGroupData[{
Cell[39114, 784, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[39490, 795, 917, 24, 70, "Text"],
Cell[40410, 821, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[40750, 832, 470, 15, 70, "Text"],
Cell[CellGroupData[{
Cell[41245, 851, 847, 24, 70, "Text"],
Cell[42095, 877, 1199, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature zQ4p4opQKpMuVA0akbqn6MKe *)
