(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     29215,        727]
NotebookOptionsPosition[     28143,        684]
NotebookOutlinePosition[     28514,        700]
CellTagsIndexPosition[     28471,        697]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Modeling of the Drug Concentration in the Blood by Repeated Intravascular \
Dosing\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ke", "=", 
     FractionBox[
      RowBox[{"Log", "[", "2", "]"}], "hl"]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Grid", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(min\)]\)=\>\"", ",", 
            RowBox[{"N", "[", 
             RowBox[{
              RowBox[{
               FractionBox["m0", "V"], 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{" ", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ke", " ", "\[Tau]"}]]}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"ke", " ", "\[Tau]"}]]}]], "-", "1"}], ")"}]}], 
              ",", "3"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(max\)]\)=\>\"", ",", 
            RowBox[{"N", "[", 
             RowBox[{
              RowBox[{
               FractionBox["m0", "V"], 
               FractionBox[
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"ke", " ", "\[Tau]"}]], 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"ke", " ", "\[Tau]"}]]}]]}], ",", "3"}], "]"}]}], 
           "}"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Spacer", "[", "20", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox["m00", "V"], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "ke"}], " ", "t"}]]}], "+", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"i", "=", "1"}], "n"], 
             RowBox[{
              FractionBox["m0", "V"], " ", 
              RowBox[{"UnitStep", "[", 
               RowBox[{"t", "-", 
                RowBox[{"i", " ", "\[Tau]"}]}], "]"}], 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"-", "ke"}], " ", 
                RowBox[{"(", 
                 RowBox[{"t", "-", 
                  RowBox[{"i", " ", "\[Tau]"}]}], ")"}]}]]}]}]}], ",", 
           RowBox[{
            FractionBox["m0", "V"], 
            FractionBox[
             RowBox[{" ", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"ke", " ", "\[Tau]"}]]}], 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"ke", " ", "\[Tau]"}]]}]]}], ",", 
           RowBox[{
            FractionBox["m0", "V"], 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{" ", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"ke", " ", "\[Tau]"}]]}], 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"ke", " ", "\[Tau]"}]]}]], "-", "1"}], ")"}]}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "range"}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"300", ",", "200"}], "}"}]}], ",", 
         RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<t (\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\"", ",", 
            "\"\<c (\!\(\*FractionBox[\(mg\), \(l\)]\))\>\""}], "}"}]}]}], 
        "]"}]}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
   "\"\<Drug concentration in the blood \\n by repeated intravascular \
dosing\>\"", ",", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V", ",", "5", ",", "\"\<Blood volume (\!\(\*
StyleBox[\"l\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "1", ",", "7", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"hl", ",", "8", ",", "\"\<Half-life (\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "0.1", ",", "48", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m00", ",", "500", ",", "\"\<First (loading) dose (\!\(\*
StyleBox[\"mg\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "0", ",", "1000", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\"\<Repeated (maintenance) dosing\>\"", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "4", ",", "\"\<\[Tau] (\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "1", ",", "48", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", "500", ",", "\"\<Dose (\!\(\*
StyleBox[\"mg\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "0", ",", "1000", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "50", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", "Delimiter", 
   ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "range", ",", "200", ",", 
       "\"\<PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)\>\""}], "}"}], ",",
      "0", ",", "1000", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "48", ",", "\"\<Total time (\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}], ",", "1", ",", "168", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4234616526833344`*^9, 3.4234616707893696`*^9}, {
   3.4234617117682943`*^9, 3.423461890795723*^9}, 3.4234619809854097`*^9, {
   3.4234620289543858`*^9, 3.4234620380474606`*^9}, {3.423462196284995*^9, 
   3.4234622054982433`*^9}, {3.4234622573227634`*^9, 
   3.4234622661855073`*^9}, {3.4234622979511843`*^9, 3.423462316618026*^9}, {
   3.4234628320291505`*^9, 3.423462918763869*^9}, {3.4234629503593006`*^9, 
   3.4234630161338797`*^9}, {3.423463198265773*^9, 3.4234632144891005`*^9}, {
   3.4234632775998497`*^9, 3.4234632813252068`*^9}, {3.4234633788854914`*^9, 
   3.4234635045061245`*^9}, {3.4234635595753107`*^9, 3.423463577791504*^9}, {
   3.4234636845450077`*^9, 3.423463686367629*^9}, {3.4234638460372224`*^9, 
   3.4234639149663377`*^9}, {3.4235041035668736`*^9, 3.42350410754259*^9}, {
   3.4240185805566587`*^9, 3.424018586875745*^9}, {3.424018765953246*^9, 
   3.4240187839691515`*^9}, {3.424018850544883*^9, 3.424018937099342*^9}, {
   3.4240190365623627`*^9, 3.4240190539974327`*^9}, {3.424019088947689*^9, 
   3.4240191070937815`*^9}, {3.42401914234447*^9, 3.424019143105564*^9}, {
   3.4240200968569913`*^9, 3.4240201270003357`*^9}, {3.4254537174033856`*^9, 
   3.425453728068722*^9}, {3.425453820211216*^9, 3.4254538583059936`*^9}, {
   3.4254541799384785`*^9, 3.425454224542616*^9}, {3.425454267133859*^9, 
   3.4254543482404847`*^9}, {3.43629640003125*^9, 3.43629642425*^9}, {
   3.43629653190625*^9, 3.436296547515625*^9}, {3.436296580703125*^9, 
   3.4362965935*^9}, {3.4362966443125*^9, 3.436296649265625*^9}, {
   3.436296810078125*^9, 3.436296867703125*^9}, {3.436296937515625*^9, 
   3.436296937734375*^9}, {3.436298764640625*^9, 3.436298786015625*^9}, {
   3.436298880359375*^9, 3.436299000875*^9}, {3.436299036578125*^9, 
   3.436299048640625*^9}, {3.43629909696875*^9, 3.436299144828125*^9}, {
   3.436299208140625*^9, 3.436299246046875*^9}, {3.43629927840625*^9, 
   3.436299281640625*^9}, {3.43629931703125*^9, 3.436299334203125*^9}, {
   3.436299423828125*^9, 3.43629949590625*^9}, {3.436299635421875*^9, 
   3.436299683703125*^9}, {3.436299729453125*^9, 3.436299735796875*^9}, {
   3.43629980365625*^9, 3.436299840921875*^9}, {3.436299895390625*^9, 
   3.436299913921875*^9}, {3.436299949765625*^9, 3.436299959109375*^9}, 
   3.43630013034375*^9, {3.436300194359375*^9, 3.436300320515625*^9}, {
   3.4363003796875*^9, 3.436300384421875*^9}, {3.4363004198125*^9, 
   3.43630042078125*^9}, {3.43645953759375*^9, 3.43645954115625*^9}, {
   3.436459656359375*^9, 3.4364598035625*^9}, {3.43645983709375*^9, 
   3.436459892734375*^9}, {3.43655354653125*^9, 3.43655354978125*^9}, {
   3.436553600578125*^9, 3.436553620046875*^9}, 3.436553655203125*^9, {
   3.43655381903125*^9, 3.4365538263125*^9}},
 CellID->178778280],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`hl$$ = 8, $CellContext`m0$$ = 
    500, $CellContext`m00$$ = 500, $CellContext`n$$ = 
    6, $CellContext`range$$ = 200, $CellContext`T$$ = 48, $CellContext`V$$ = 
    5, $CellContext`\[Tau]$$ = 9, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[
      "Drug concentration in the blood \n by repeated intravascular dosing"], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`V$$], 5, 
       "Blood volume (\!\(\*\nStyleBox[\"l\",\nFontSlant->\"Italic\"]\))"}, 1,
       7}, {{
       Hold[$CellContext`hl$$], 8, 
       "Half-life (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 0.1, 
      48}, {{
       Hold[$CellContext`m00$$], 500, 
       "First (loading) dose (\!\(\*\nStyleBox[\"mg\",\n\
FontSlant->\"Italic\"]\))"}, 0, 1000}, {
      Hold["Repeated (maintaining) dosing"], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`\[Tau]$$], 4, 
       "\[Tau] (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 1, 48, 
      1}, {{
       Hold[$CellContext`m0$$], 500, 
       "Dose (\!\(\*\nStyleBox[\"mg\",\nFontSlant->\"Italic\"]\))"}, 0, 
      1000}, {
      Hold[$CellContext`n$$], 0, 50, 1}, {{
       Hold[$CellContext`range$$], 200, 
       "PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)"}, 0, 1000}, {{
       Hold[$CellContext`T$$], 48, 
       "Total time (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 1, 
      168, 1}}, Typeset`size$$ = {307.5, {229., 15.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, $CellContext`V$1359$$ =
     0, $CellContext`hl$1360$$ = 0, $CellContext`m00$1361$$ = 
    0, $CellContext`\[Tau]$1362$$ = 0, $CellContext`m0$1363$$ = 
    0, $CellContext`n$1364$$ = 0, $CellContext`range$1365$$ = 
    0, $CellContext`T$1366$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`hl$$ = 8, $CellContext`m0$$ = 
        500, $CellContext`m00$$ = 500, $CellContext`n$$ = 
        0, $CellContext`range$$ = 200, $CellContext`T$$ = 
        48, $CellContext`V$$ = 5, $CellContext`\[Tau]$$ = 4}, 
      "ControllerVariables" :> {
        Hold[$CellContext`V$$, $CellContext`V$1359$$, 0], 
        Hold[$CellContext`hl$$, $CellContext`hl$1360$$, 0], 
        Hold[$CellContext`m00$$, $CellContext`m00$1361$$, 0], 
        Hold[$CellContext`\[Tau]$$, $CellContext`\[Tau]$1362$$, 0], 
        Hold[$CellContext`m0$$, $CellContext`m0$1363$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$1364$$, 0], 
        Hold[$CellContext`range$$, $CellContext`range$1365$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$1366$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`ke = Log[2]/$CellContext`hl$$; Row[{
          Grid[{{"\!\(\*SubscriptBox[\(c\), \(min\)]\)=", 
             
             N[($CellContext`m0$$/$CellContext`V$$) (
               E^($CellContext`ke $CellContext`\[Tau]$$)/(-1 + 
                E^($CellContext`ke $CellContext`\[Tau]$$)) - 1), 3]}, {
            "\!\(\*SubscriptBox[\(c\), \(max\)]\)=", 
             
             N[($CellContext`m0$$/$CellContext`V$$) (
               E^($CellContext`ke $CellContext`\[Tau]$$)/(-1 + 
               E^($CellContext`ke $CellContext`\[Tau]$$))), 3]}}], 
          Spacer[20], 
          
          Plot[{($CellContext`m00$$/$CellContext`V$$) 
             E^((-$CellContext`ke) $CellContext`t) + 
            Sum[(($CellContext`m0$$/$CellContext`V$$) 
               UnitStep[$CellContext`t - $CellContext`i \
$CellContext`\[Tau]$$]) 
              E^((-$CellContext`ke) ($CellContext`t - $CellContext`i \
$CellContext`\[Tau]$$)), {$CellContext`i, 
               1, $CellContext`n$$}], ($CellContext`m0$$/$CellContext`V$$) (
             E^($CellContext`ke $CellContext`\[Tau]$$)/(-1 + 
             E^($CellContext`ke $CellContext`\[Tau]$$))), \
($CellContext`m0$$/$CellContext`V$$) (
             E^($CellContext`ke $CellContext`\[Tau]$$)/(-1 + 
              E^($CellContext`ke $CellContext`\[Tau]$$)) - 
             1)}, {$CellContext`t, 0, $CellContext`T$$}, 
           PlotRange -> {0, $CellContext`range$$}, ImageSize -> {300, 200}, 
           Exclusions -> None, 
           AxesLabel -> {
            "t (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))", 
             "c (\!\(\*FractionBox[\(mg\), \(l\)]\))"}]}]), 
      "Specifications" :> {
       "Drug concentration in the blood \n by repeated intravascular dosing", 
        Delimiter, {{$CellContext`V$$, 5, 
          "Blood volume (\!\(\*\nStyleBox[\"l\",\nFontSlant->\"Italic\"]\))"},
          1, 7, Appearance -> "Labeled", ImageSize -> 
         Small}, {{$CellContext`hl$$, 8, 
          "Half-life (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 
         0.1, 48, Appearance -> "Labeled", ImageSize -> Small}, 
        Delimiter, {{$CellContext`m00$$, 500, 
          "First (loading) dose (\!\(\*\nStyleBox[\"mg\",\n\
FontSlant->\"Italic\"]\))"}, 0, 1000, Appearance -> "Labeled", ImageSize -> 
         Small}, "Repeated (maintaining) dosing", {{$CellContext`\[Tau]$$, 4, 
          "\[Tau] (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 1, 
         48, 1, Appearance -> "Labeled", ImageSize -> 
         Small}, {{$CellContext`m0$$, 500, 
          "Dose (\!\(\*\nStyleBox[\"mg\",\nFontSlant->\"Italic\"]\))"}, 0, 
         1000, Appearance -> "Labeled", ImageSize -> 
         Small}, {$CellContext`n$$, 0, 50, 1, Appearance -> "Labeled", 
         ImageSize -> Small}, 
        Delimiter, {{$CellContext`range$$, 200, 
          "PlotRange \!\(\*SubscriptBox[\(c\), \(max\)]\)"}, 0, 1000, 
         ImageSize -> 
         Small}, {{$CellContext`T$$, 48, 
          "Total time (\!\(\*\nStyleBox[\"h\",\nFontSlant->\"Italic\"]\))"}, 
         1, 168, 1, Appearance -> "Labeled", ImageSize -> Small}}, 
      "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{621., {149., 154.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.423461893539669*^9, 3.423461982767973*^9, 3.423462041632616*^9, 
   3.4234622066298704`*^9, 3.4234622667362995`*^9, 3.423462317809739*^9, {
   3.423462861992235*^9, 3.423462919384762*^9}, {3.423462986010565*^9, 
   3.423463018587408*^9}, 3.423463218775264*^9, 3.4234632819460993`*^9, {
   3.4234634798006*^9, 3.423463505757925*^9}, 3.423463578512541*^9, 
   3.4234636875292993`*^9, {3.4234638651647263`*^9, 3.4234639163383102`*^9}, 
   3.423504108113411*^9, 3.4239726778851585`*^9, 3.4240185888185387`*^9, 
   3.424018942166628*^9, 3.424019055649809*^9, 3.4240191109893837`*^9, 
   3.4240191439367595`*^9, {3.424020103937172*^9, 3.4240201280518475`*^9}, 
   3.4254538661873264`*^9, 3.425454350013034*^9, 3.4362966020625*^9, 
   3.4362966500625*^9, 3.436296813609375*^9, {3.436296848296875*^9, 
   3.436296869578125*^9}, 3.436296939796875*^9, 3.4362987965625*^9, 
   3.436298938671875*^9, 3.436299006265625*^9, 3.436299049375*^9, 
   3.43629918628125*^9, 3.436299247875*^9, 3.436299497296875*^9, 
   3.4362996061875*^9, 3.436299684515625*^9, 3.436299737296875*^9, 
   3.436299842125*^9, {3.43629989684375*^9, 3.436299917296875*^9}, 
   3.43629995978125*^9, {3.436300312265625*^9, 3.43630038571875*^9}, 
   3.436300423078125*^9, 3.4364595585625*^9, 3.43645966328125*^9, {
   3.436459706109375*^9, 3.436459729109375*^9}, 3.43645977421875*^9, 
   3.43645984278125*^9, 3.436459893984375*^9, {3.436553585296875*^9, 
   3.436553621*^9}},
 CellID->100582831]
}, {2}]],

Cell[CellGroupData[{

Cell["Description", "Section",
 CellChangeTimes->{{3.4559897851875*^9, 3.455989790390625*^9}}],

Cell["\<\
The user study interactively the blood level curve (concentration of the drug \
in the blood) under repeated dosing described by the simple impulsive system:\
\>", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240192663728137`*^9, 3.4240193173861675`*^9}, {
   3.4254514888488817`*^9, 3.425451490561344*^9}, {3.4254539568777328`*^9, 
   3.4254540157423763`*^9}, {3.4254540460159073`*^9, 
   3.4254541206732593`*^9}, {3.436294648265625*^9, 3.436294653265625*^9}, {
   3.436294695421875*^9, 3.436294747921875*^9}, 3.43629527096875*^9, {
   3.436295312484375*^9, 3.436295316140625*^9}, {3.43629628190625*^9, 
   3.436296283203125*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"c", "'"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["k", "e"]}], "c", " "}]}], TraditionalForm]], "InlineMath"],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[NotEqual]", 
    RowBox[{"n", " ", "\[Tau]"}]}], TraditionalForm]], "InlineMath"],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"c", "(", 
     RowBox[{
      RowBox[{"n", " ", "\[Tau]"}], "+", "0"}], ")"}], "=", 
    RowBox[{
     RowBox[{"c", "(", 
      RowBox[{
       RowBox[{"n", " ", "\[Tau]"}], "-", "0"}], ")"}], "+", 
     SubscriptBox["c", "0"]}]}], TraditionalForm]], "InlineMath"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"n", " ", "=", " ", "1"}], ",", " ", "2", ",", " ", "..."}], 
    ")"}], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"c", "(", "0", ")"}], "=", 
    SubscriptBox["c", "00"]}], TraditionalForm]], "InlineMath"],
 " "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424019328552223*^9, 3.4240195879852695`*^9}},
 CellID->648775985],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", 
    RowBox[{"c", "(", "t", ")"}]}], TraditionalForm]], "InlineMath"],
 " (typically given in ",
 Cell[BoxData[
  FormBox[
   FractionBox["mg", "l"], TraditionalForm]], "InlineMath"],
 ") is the concentration of the drug in the blood depending on the time, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "e"], TraditionalForm]], "InlineMath"],
 " is the rate of elimination of the drug (found experimentally), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "00"], TraditionalForm]], "InlineMath"],
 " is the first dose, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "0"], TraditionalForm]], "InlineMath"],
 " is the repeated dose, both are given in mg. The time between the doses is \
\[Tau] typically given in minutes or hours. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "min"], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "max"], TraditionalForm]], "InlineMath"],
 " are the extremal values of the asymtotically stable periodic equilibrium. "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4240195902985964`*^9, 3.424019717281188*^9}, {
   3.4240197613745914`*^9, 3.424019783366214*^9}, {3.424019820299321*^9, 
   3.4240198829894648`*^9}, {3.4254513065167007`*^9, 
   3.4254513119645343`*^9}, {3.4254513618362465`*^9, 3.425451458745595*^9}, {
   3.42545152876628*^9, 3.4254515313700237`*^9}, {3.425452046460688*^9, 
   3.425452061412187*^9}, {3.4254539479549026`*^9, 3.425453948625867*^9}, {
   3.436295254984375*^9, 3.436295283671875*^9}, {3.436295395375*^9, 
   3.436295468234375*^9}, {3.4362955540625*^9, 3.436295555828125*^9}},
 CellID->143509364]
}, Open  ]],

Cell[CellGroupData[{

Cell["Details", "Section",
 CellChangeTimes->{{3.455989799109375*^9, 3.45598980034375*^9}}],

Cell[TextData[{
 "This model can be used for drugs with elimination of first order, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"c", "'"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["k", "e"]}], "c", " "}]}], TraditionalForm]], "InlineMath"],
 ",  the speed of elimination is proportional to the concentration. The rate \
of elimination is given to every drug by experiments. The explicite formulas \
are obtained by solving the given impulsive system. In the practice,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "min"], TraditionalForm]], "InlineMath"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "max"], TraditionalForm]], "InlineMath"],
 " must be inside the so called region of therapy to avoid over- and \
underdosing. This model (using the same notations) is part of the Biopharmacy \
courses for Pharmacy students. "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424020504933777*^9, 3.4240205345063*^9}, {
   3.4254516036339345`*^9, 3.425451854654885*^9}, {3.4254519905202494`*^9, 
   3.4254520318596926`*^9}, {3.425452126005067*^9, 3.4254521395745792`*^9}, {
   3.4254535705121665`*^9, 3.4254535977713633`*^9}, {3.43629562753125*^9, 
   3.436295637984375*^9}, {3.436297065515625*^9, 3.43629707090625*^9}},
 TextJustification->1.,
 CellID->616437312],

Cell["\<\
For demonstrational purpose (better visibility of the effects), the scaling \
is not restricted. \
\>", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.424020504933777*^9, 3.4240205345063*^9}, {
   3.4254516036339345`*^9, 3.425451854654885*^9}, {3.4254519905202494`*^9, 
   3.4254520318596926`*^9}, {3.425452126005067*^9, 3.4254522368544607`*^9}, {
   3.425452267798957*^9, 3.4254523515393696`*^9}, {3.4254523879817715`*^9, 
   3.4254525752310224`*^9}, 3.43629570009375*^9},
 TextJustification->1.,
 CellID->305183260],

Cell[TextData[{
 "In the practice, the dose of the drug (mass is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "0"], TraditionalForm]]],
 " and the volume is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "0"], TraditionalForm]]],
 ")  is given in injection at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]], "InlineMath"],
 ", and the mass of the drug  will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"m", "(", 
     RowBox[{
      SubscriptBox["t", "0"], "+", "0"}], ")"}], "=", 
    RowBox[{
     RowBox[{"m", "(", 
      RowBox[{
       SubscriptBox["t", "0"], "-", "0"}], ")"}], "+", 
     SubscriptBox["m", "0"]}]}], TraditionalForm]], "InlineMath"],
 ". Then, let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 " be the total volume of the blood (including the drug injected). For the \
concentration we have"
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4254526278366656`*^9, 3.4254526406250544`*^9}, {
   3.425452922460314*^9, 3.4254530126900578`*^9}, {3.43629580021875*^9, 
   3.43629580834375*^9}, {3.436295936765625*^9, 3.43629603978125*^9}, {
   3.43629607978125*^9, 3.436296085625*^9}},
 TextJustification->1.,
 CellID->458811223],

Cell[TextData[{
 "  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"c", "(", 
      RowBox[{
       SubscriptBox["t", "0"], "+", "0"}], ")"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"m", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["t", "0"], "+", "0"}], ")"}]}], 
       RowBox[{"V", "(", 
        RowBox[{
         SubscriptBox["t", "0"], "+", "0"}], ")"}]], "=", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"m", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["t", "0"], "-", "0"}], ")"}]}], "+", 
          SubscriptBox["m", "0"]}], 
         RowBox[{
          RowBox[{"V", "(", 
           RowBox[{
            SubscriptBox["t", "0"], "-", "0"}], ")"}], "+", 
          SubscriptBox["v", "0"]}]], "\[TildeTilde]", 
        RowBox[{
         FractionBox[
          RowBox[{"m", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["t", "0"], "-", "0"}], ")"}]}], 
          RowBox[{"V", "(", 
           RowBox[{
            SubscriptBox["t", "0"], "-", "0"}], ")"}]], "+", 
         FractionBox[
          SubscriptBox["m", "0"], 
          RowBox[{"V", "(", 
           RowBox[{"t", "+", "0"}], ")"}]]}]}], "=", 
       RowBox[{
        RowBox[{"c", "(", 
         RowBox[{
          SubscriptBox["t", "0"], "-", "0"}], ")"}], "+", 
        SubscriptBox["c", "0"]}]}]}]}], ","}], TraditionalForm]], 
  "InlineMath"],
 " "
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.42545315826939*^9, 3.42545316687176*^9}, {
   3.436295815140625*^9, 3.436295815140625*^9}, {3.436295849875*^9, 
   3.43629586984375*^9}},
 TextJustification->1.,
 CellID->11372106],

Cell[TextData[{
 "valid only if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "0"], " ", 
    RowBox[{"<<", "V"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]], "InlineMath"],
 ", what is a natural assumption. It can happen that concentration becomes \
too big. In this case, other models desrcibe the elimination (such as \
Michaelis-Menten kinetics) ."
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4254531689647694`*^9, 3.425453215141168*^9}, {
   3.4254532474676514`*^9, 3.4254532502015824`*^9}, {3.4254532958972893`*^9, 
   3.425453390202894*^9}, {3.4254534334751167`*^9, 3.425453444490957*^9}, {
   3.436296103796875*^9, 3.43629613171875*^9}, {3.436296174875*^9, 
   3.4362961940625*^9}, {3.43629625171875*^9, 3.436296252609375*^9}},
 TextJustification->1.,
 CellID->524513656]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{618, 566},
WindowMargins->{{55, Automatic}, {Automatic, 7}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 110, 3, 77, "Subtitle"],
Cell[CellGroupData[{
Cell[702, 29, 9815, 218, 722, "Input",
 CellID->178778280],
Cell[10520, 249, 8194, 152, 320, "Output",
 CellID->100582831]
}, {2}]],
Cell[CellGroupData[{
Cell[18748, 406, 94, 1, 71, "Section"],
Cell[18845, 409, 651, 11, 47, "Text"],
Cell[19499, 422, 1120, 42, 29, "Text",
 CellID->648775985],
Cell[20622, 466, 1713, 42, 90, "Text",
 CellID->143509364]
}, Open  ]],
Cell[CellGroupData[{
Cell[22372, 513, 91, 1, 71, "Section"],
Cell[22466, 516, 1321, 30, 101, "Text",
 CellID->616437312],
Cell[23790, 548, 534, 11, 29, "Text",
 CellID->305183260],
Cell[24327, 561, 1254, 38, 65, "Text",
 CellID->458811223],
Cell[25584, 601, 1711, 58, 43, "Text",
 CellID->11372106],
Cell[27298, 661, 817, 19, 47, "Text",
 CellID->524513656]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

